@@ -1,7 +1,10 @@
-use std::{collections::HashMap, str::FromStr};
+use std::str::FromStr;
 
 use crate::{
-    collections::key_map::{Handle, KeyMap},
+    collections::{
+        handle_table::{Handle, HandleTable},
+        hash_map::CaoHashMap,
+    },
     compiler::CardIndex,
     VarName,
 };
@@ -9,13 +12,13 @@ use crate::{version, VariableId};
 
 #[derive(Debug, Default, Clone)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
-pub struct Labels(pub KeyMap<Label>);
+pub struct Labels(pub HandleTable<Label>);
 
 #[derive(Debug, Default, Clone)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct Variables {
-    pub ids: KeyMap<VariableId>,
-    pub names: KeyMap<VarName>,
+    pub ids: HandleTable<VariableId>,
+    pub names: HandleTable<VarName>,
 }
 
 #[derive(Debug, Clone, Default)]
@@ -41,7 +44,7 @@ pub struct CaoCompiledProgram {
     pub labels: Labels,
     pub variables: Variables,
     pub cao_lang_version: (u8, u8, u16),
-    pub trace: HashMap<usize, CardIndex>,
+    pub trace: CaoHashMap<u32, CardIndex>,
 }
 
 impl CaoCompiledProgram {
